/**
 *  OdetteJ - Open Source Odette FTP implementation in Java(TM).
 *  Copyright (C) 2005 Fossil E-Commerce, http://www.fossilec.com
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ------------------------------------------------------------------------
 *  $Id: OdetteFTPEntity.java,v 1.9 2005/07/11 04:17:08 rmarins Exp $
 *  ------------------------------------------------------------------------
 */

package org.fossilec.odettej;

import java.util.Date;

import org.fossilec.odettej.service.EndSessionReason;

/**
 * This is the object representation of a Odette FTP entity, or peer, as defined
 * in the protocol specification. It provide the File Transfer Service layer
 * required for operating in both <i>Speaker</i> or <i>Listener</i> states.
 * <p>
 * A class instance must be loaded from the <code>Session</code> object. If
 * you would like to start an <code>OdetteFTPEntity</code> as an <i>Initiator</i>
 * you must execute the <code>connect()</code> method, otherwise the
 * <code>acceptConnection()</code> should be invoked to start the class
 * instance as a <i>Responder</i>.
 * 
 * @author Rafael Marins
 */
public interface OdetteFTPEntity {

	public Session getContext();

	public void startSession() throws OdetteFTPException;

	public void startFile(VirtualFile file, String destination,
			String originator, String userData, String reserved)
			throws OdetteFTPException;

	public void dataRegime() throws OdetteFTPException;

	public void closeFile(int recordCount, long unitCount)
			throws OdetteFTPException;

	public void changeDirection() throws OdetteFTPException;

	public void endToEndResponse(String datasetName, Date fileDateTime,
			String destination, String originator, String userData,
			String reserved) throws OdetteFTPException;

	public void release() throws OdetteFTPException;

	public void abort(EndSessionReason error) throws OdetteFTPException;

	public boolean isConnected() throws OdetteFTPException;

}