/**
 *  OdetteJ - Open Source Odette FTP implementation in Java(TM).
 *  Copyright (C) 2005 Fossil E-Commerce, http://www.fossilec.com
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ------------------------------------------------------------------------
 *  $Id: PreferencesUtil.java,v 1.3 2005/08/16 03:50:48 rmarins Exp $
 *  ------------------------------------------------------------------------
 */

package org.fossilec.odettej;

import java.util.Properties;

import org.fossilec.odettej.service.TransferMode;

public class PreferencesUtil {

	private Properties preferences;

	public PreferencesUtil(Properties properties) {
		super();

		this.preferences = properties;
	}

	public static int getInt(Properties props, String key) {
		String value = props.getProperty(key);
		return Integer.parseInt(value);
	}

	public static boolean getBoolean(Properties props, String key) {
		String value = props.getProperty(key);
		return Boolean.valueOf(value).booleanValue();
	}

	public boolean getBoolean(String key) {
		return getBoolean(preferences, key);
	}

	static Properties fillDefaultVariables(Properties props) {

		setPropertyIfNotExists(props, "odette.buffer-size", "2048");
		setPropertyIfNotExists(props, "odette.window-size", "64");
		setPropertyIfNotExists(props, "odette.restart", "true");
		setPropertyIfNotExists(props, "odette.compression", "true");
		setPropertyIfNotExists(props, "odette.special-logic", "false");
		setPropertyIfNotExists(props, "odette.mode", TransferMode.BOTH
				.toString());
		setPropertyIfNotExists(props, "odette.strict.format", "true");

		// Stream Transmission Buffer
		setPropertyIfNotExists(props, "odette.stb", "true");

		setPropertyIfNotExists(props, "odette.transport.class",
				"org.fossilec.odettej.transport.tcp.TCPTransport");
		setPropertyIfNotExists(props, "odette.transport.tcp.port", "3305");

		return props;
	}

	private static void setPropertyIfNotExists(Properties props, String key,
			String value) {
		if (!props.containsKey(key)) {
			props.setProperty(key, value);
		}
	}

	public static TransferMode getTransferMode(Properties props) {

		char initial = props.getProperty("odette.mode").charAt(0);
		TransferMode mode = (TransferMode) TransferMode.parse(String
				.valueOf(initial));

		return mode;
	}

	public String getCalledAddress() {
		return preferences.getProperty("odette.called-address");
	}

	public String getCallingAddress() {
		return preferences.getProperty("odette.calling-address");
	}

	public TransferMode getTransferMode() {
		return getTransferMode(preferences);
	}

	static void setTransferMode(Properties props, TransferMode mode) {
		props.setProperty("odette.mode", mode.toString());
	}

	public static boolean isRestartSupported(Properties props) {
		String restart = props.getProperty("odette.restart");
		return Boolean.valueOf(restart).booleanValue();
	}

	public boolean isRestartSupported() {
		return isRestartSupported(preferences);
	}

	public boolean isUsingStrictFormat() {
		return getBoolean("odette.strict.format");
	}

	static void setRestartSupport(Properties props, boolean set) {
		props.setProperty("odette.restart", Boolean.toString(set));
	}

	public static void setTransport(Properties props, String className) {
		props.setProperty("odette.transport.class", className);
	}

	public void setTransport(String className) {
		setTransport(preferences, className);
	}

	static String getTransport(Properties props) {
		return props.getProperty("odette.transport.class");
	}

	public String getLocalUser() {
		return preferences.getProperty("odette.user.code", "");
	}

	public String getLocalPassword() {
		return preferences.getProperty("odette.user.password", "");
	}

	public int getBufferSize() {
		String sdeb = preferences.getProperty("odette.buffer-size", "0");
		return Integer.parseInt(sdeb);
	}

	public String getUserData() {
		return preferences.getProperty("odette.user-data", "");
	}

	public int getWindowSize() {
		String window = preferences.getProperty("odette.window-size", "0");
		return Integer.parseInt(window);
	}

	public boolean hasSpecialLogic() {
		String slog = preferences.getProperty("odette.special-logic", "false");
		return Boolean.valueOf(slog).booleanValue();
	}

	public boolean isCompressionSupported() {
		String comp = preferences.getProperty("odette.compression", "false");
		return Boolean.valueOf(comp).booleanValue();
	}

	public String getReservedParam() {
		return preferences.getProperty("odette.param", "");
	}

	public void setWindowSize(int window) {
		preferences.setProperty("odette.window-size", String.valueOf(window));
	}

	public void setCompressionSupport(boolean set) {
		preferences.setProperty("odette.compression", String.valueOf(set));
	}

	public void setRestartSupport(boolean set) {
		preferences.setProperty("odette.restart", String.valueOf(set));
	}

	public void setTransferMode(TransferMode mode) {
		preferences.setProperty("odette.mode", mode.toString());
	}

	public void setSpecialLogic(boolean set) {
		preferences.setProperty("odette.special-logic", String.valueOf(set));
	}

	public void setBufferSize(int sdeb) {
		preferences.setProperty("odette.buffer-size", String.valueOf(sdeb));
	}

	public static void setLocalUser(Properties props, String userCode) {
		props.setProperty("odette.user.code", userCode);
	}

	public static void setLocalPassword(Properties props, String password) {
		props.setProperty("odette.user.password", password);
	}
}
